import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/ui/svga_download_widget.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Model/model_live_user_list_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/generated/l10n.dart';

class WidgetLiveHeaderList extends StatelessWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveUserListUsers listModel;
  WidgetLiveHeaderList({required this.listModel, required this.clickCallBack});
  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Visibility(
            visible: listModel.type != null,
            child: Container(
              margin: EdgeInsets.only(right: 10.w),
              child: UtilsLiveImage.getIconByPath(
                listModel.type == 0
                    ? 'icon_live_apply_voice_Application'
                    : 'icon_live_video_Application',
              ),
            )),
        GestureDetector(
          child: ClipRRect(
            borderRadius: BorderRadius.circular(25.w),
            child: SizedBox(
              width: 50.w,
              height: 50.w,
              child: SvgaDownloadWidget(
                listModel.headFrame?.iconJson ?? '',
                widht: 50.w,
                headImage: listModel.headImage,
                iconUrl: listModel.headFrame?.icon,
              ),
            ),
          ),
          onTap: () {
            clickCallBack(ConfigLiveMethon.liveClickUserInfo, listModel.userId);
          },
        ),
        Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              children: [
                Container(
                  // width: 180.w,
                  constraints: BoxConstraints(
                    maxWidth: 180.w
                  ),
                  // color: Colors.red,
                  padding: const EdgeInsets.only(left: 10),
                  // constraints: BoxConstraints(maxWidth: 120.w),
                  child: Text(
                    listModel.nickname ?? '',
                    maxLines: 1,
                    overflow: TextOverflow.ellipsis,
                    style: TextStyle(
                        fontSize: 18,
                        color: UtilsLiveColor.hexToColor("#FFFFFF"),
                        fontWeight: FontWeight.bold,
                        wordSpacing: -1,
                        decoration: TextDecoration.none),
                  ),
                ),
                for (var i = 0; i < (listModel.achieves ?? []).length; i++)
                  Padding(
                    padding: const EdgeInsets.only(left: 5),
                    child: UtilsLiveImage.getLoadWidget(
                        listModel.achieves?[i].icon,
                        width: 20.w,
                        height: 20.w),
                  )
              ],
            ),
            const SizedBox(
              height: 3,
            ),
            Container(
              height: 20,
              margin: const EdgeInsets.only(left: 10),
              padding: const EdgeInsets.symmetric(horizontal: 7),
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10),
                  color: listModel.isHost == 0
                      ? UtilsLiveColor.hexToColor("#FFFFFF").withOpacity(0.1)
                      : listModel.userId ==
                              ProviderLiveInfoEntity().infoEntity.userId
                          ? const Color(0xffFB5C9A)
                          : UtilsLiveColor.hexToColor('#EB6B00')),
              // Color(0xffFB5C9A)
              child: Row(
                children: [
                  Text(
                    getUserType(),
                    style: const TextStyle(
                        color: Colors.white,
                        fontSize: 12,
                        fontWeight: FontWeight.normal,
                        decoration: TextDecoration.none),
                  )
                ],
              ),
            )
          ],
        ),
      ],
    );
  }

  String getUserType() {
    if (listModel.isAnchor != null) {
      return listModel.isAnchor == 1
          ? S.current.Live_Anchor
          : S.current.Live_GuestInfo;
    } else {
      return listModel.isHost == 0
          ? S.current.Live_GuestInfo
          : listModel.userId == ProviderLiveInfoEntity().infoEntity.userId
              ? S.current.Live_Owners
              : S.current.Live_Anchor;
    }
  }
}
