import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/utils/download_utils.dart';
import 'package:mmoo_live_room/Config/config_live_globalkey.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/Widget/widget_live_svga_show.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:svgaplayer_flutter/parser.dart';
import 'package:svgaplayer_flutter/player.dart';

class WidgetLiveRideShow extends StatefulWidget {
  WidgetLiveRideShow() : super(key: ConfigLiveGlobalkey.liveRideShowKey);
  @override
  WidgetLiveRideShowState createState() => WidgetLiveRideShowState();
}

class WidgetLiveRideShowState extends State<WidgetLiveRideShow>
    with SingleTickerProviderStateMixin {
  late SVGAAnimationController animationController;

  List<ModelLiveRideAnimation> _animationData = [];
  ModelLiveRideAnimation? _rideAnimation;
  @override
  Widget build(BuildContext context) {
    return Center(
      child: SizedBox(
        width: 1.sw,
        // color: Colors.red,
        // height: 300.w,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            SizedBox(
              height: 150.w,
            ),
            animationController.videoItem != null
                ?SizedBox(
                  height: 150.w,
                  child:  SVGAImage(animationController),
                )
                : Container(),
            Visibility(
                visible: _rideAnimation != null &&
                    animationController.videoItem != null &&
                    _rideAnimation?.frameicon != null,
                child: Row(
                  children: [
                    Container(
                      margin: const EdgeInsets.only(left: 5),
                      width: 185.w,
                      height: 70.w,
                      child: Stack(
                        children: [
                          Positioned(
                            right: 0,
                            top: 10.w,
                            child: UtilsLiveImage.getIconByPath(
                                'icon_live_headframe_bg'),
                            width: 150.w,
                            height: 50.w,
                          ),
                          Positioned(
                              left: 0,
                              child: Row(
                                children: [
                                  WidgetLiveSvgaShow(
                                    _rideAnimation?.incomeJson ?? '',
                                    widht: 70.w,
                                    height: 70.w,
                                    iconUrl: _rideAnimation?.frameicon,
                                    headImage: _rideAnimation?.headImage,
                                  ),
                                  Container(
                                    constraints:
                                        BoxConstraints(maxWidth: 110.w),
                                    child: Column(
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: [
                                        Text(
                                          _rideAnimation?.nickname ?? '',
                                          style: UtilsLiveTextStyle
                                              .pt16WhiteSemiBold,
                                        ),
                                        Text(
                                          S.current.Live_Enteredtheroom,
                                          style: UtilsLiveTextStyle.pt12White
                                              .copyWith(
                                                  color: Colors.white
                                                      .withOpacity(0.6)),
                                        )
                                      ],
                                    ),
                                  )
                                ],
                              )),
                        ],
                      ),
                    )
                  ],
                )),
          ],
        ),
      ),
    );
  }

  beginAnimation(ModelLiveRideAnimation rideModel) async {
    DLog("beginAnimation");
    _animationData.add(rideModel);
    if (_animationData.length == 1) {
      _rideAnimation = _animationData.first;
      await loadAnimation();
    }
  }

  removeAnimationDataSource() async {
    _animationData.removeAt(0);
    if (_animationData.isNotEmpty) {
      _rideAnimation = _animationData.first;
      loadAnimation();
    } else {
      if (mounted) {
        setState(() {
          animationController.videoItem = null;
          _rideAnimation = null;
        });
      }
    }
  }

  Future loadAnimation() async {
    if (_rideAnimation != null && _rideAnimation?.incomeJson != null) {
      Uint8List? uint8list =
          await DownloadUtils.downloadSvgaAndSave(_rideAnimation?.incomeJson);
      if (uint8list == null) {
        removeAnimationDataSource();
      } else {
        final videoItem = await SVGAParser.shared.decodeFromBuffer(uint8list);
        animationController.videoItem = videoItem;
        DLog(animationController.duration?.inMilliseconds);
        animationController.value = 0;
        animationController.forward();
        if (mounted) {
          setState(() {});
        }
      }
    } else {
      removeAnimationDataSource();
    }
  }

  @override
  void initState() {
    animationController = SVGAAnimationController(vsync: this);
    animationController.addStatusListener((status) {
      DLog(status);
      if (status == AnimationStatus.completed) {
        if (mounted) {
          setState(() {
            _rideAnimation = null;
            animationController.videoItem = null;
          });
        }
        removeAnimationDataSource();
      }
    });

    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveRideShow oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}

class ModelLiveRideAnimation {
  String? frameJson;
  String? frameicon;
  String? headImage;
  String? nickname;
  String? incomeJson;
  ModelLiveRideAnimation(
      {this.frameJson,
      this.frameicon,
      this.headImage,
      this.nickname,
      this.incomeJson});
}
