import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:mmoo_base/utils/download_utils.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:svgaplayer_flutter/parser.dart';
import 'package:svgaplayer_flutter/player.dart';

// ignore: must_be_immutable
class WidgetLiveSvgaShow extends StatefulWidget {
  final double widht;
  final String? iconUrl;
  final String svgaurl;
  final String? headImage;
  double? height;
  WidgetLiveSvgaShow(this.svgaurl,
      {Key? key,
      required this.widht,
      this.iconUrl,
      this.height,
      this.headImage})
      : super(key: key);
  @override
  WidgetLiveSvgaShowState createState() => WidgetLiveSvgaShowState();
}

class WidgetLiveSvgaShowState extends State<WidgetLiveSvgaShow>
    with SingleTickerProviderStateMixin {
  late SVGAAnimationController animationController;
  static String _svgaurl = '';
  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: widget.widht,
      height: widget.height,
      child: Stack(
        children: [
          Visibility(
              visible: widget.headImage != null,
              child: Positioned.fill(
                  child: Container(
                alignment: Alignment.center,
                width: widget.widht * (5 / 7.0),
                height: widget.widht * (5 / 7.0),
                child: ClipRRect(
                  borderRadius:
                      BorderRadius.circular(widget.widht * (5 / 7.0) * 0.5),
                  child: UtilsLiveImage.getLoadWidget(widget.headImage,
                      width: widget.widht * (5 / 7.0),
                      height: widget.widht * (5 / 7.0)),
                ),
              ))),
          Positioned.fill(
              child: (widget.svgaurl.isNotEmpty &&
                      animationController.videoItem != null)
                  ? SVGAImage(animationController)
                  : (widget.iconUrl != null
                      ? UtilsLiveImage.getLoadWidget(
                          widget.iconUrl,
                        )
                      : Container())),
        ],
      ),
    );
  }

  void loadAnimation() async {
    if (widget.svgaurl.isNotEmpty) {
      Uint8List? uint8list =
          await DownloadUtils.downloadSvgaAndSave(widget.svgaurl);
      if (uint8list == null) {
        return;
      }
      final videoItem = await SVGAParser.shared.decodeFromBuffer(uint8list);
      animationController.videoItem = videoItem;

      animationController.repeat().whenComplete(() {
        animationController.videoItem = null;
      });
      if (mounted) {
        setState(() {});
      }
    }
  }

  @override
  void initState() {
    widget.height ??= widget.widht;
    animationController = SVGAAnimationController(vsync: this);
    loadAnimation();
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveSvgaShow oldWidget) {
    if (_svgaurl != widget.svgaurl) {
      _svgaurl = widget.svgaurl;
      loadAnimation();
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
